.. autosummary::
   :toctree: generated/
   :template: autodocsumm/module-inherit.rst

   cmomy.reduction
   cmomy.resample
   cmomy.random
   cmomy.convert
   cmomy.compile



.. autosummary::
   :toctree: generated/
   :template: autodocsumm/module.rst

   cmomy.typing
